import { Kind } from 'graphql';
import { indent, getBaseTypeNode } from './utils';
import autoBind from 'auto-bind';
export class OperationVariablesToObject {
    constructor(_scalars, _convertName) {
        this._scalars = _scalars;
        this._convertName = _convertName;
        autoBind(this);
    }
    getName(node) {
        if (node.name) {
            if (typeof node.name === 'string') {
                return node.name;
            }
            return node.name.value;
        }
        else if (node.variable) {
            return node.variable.name.value;
        }
        return null;
    }
    transform(variablesNode) {
        if (!variablesNode || variablesNode.length === 0) {
            return null;
        }
        return variablesNode.map(variable => indent(this.transformVariable(variable))).join(',\n');
    }
    transformVariable(variable) {
        const baseType = typeof variable.type === 'string' ? variable.type : getBaseTypeNode(variable.type);
        const typeName = typeof baseType === 'string' ? baseType : baseType.name.value;
        const typeValue = this._scalars[typeName] ||
            this._convertName(baseType, {
                useTypesPrefix: true
            });
        const fieldName = this.getName(variable);
        const fieldType = this.wrapAstTypeWithModifiers(typeValue, variable.type);
        const hasDefaultValue = variable.defaultValue != null && typeof variable.defaultValue !== 'undefined';
        const isNonNullType = variable.type.kind === Kind.NON_NULL_TYPE;
        const formattedFieldString = this.formatFieldString(fieldName, isNonNullType, hasDefaultValue);
        const formattedTypeString = this.formatTypeString(fieldType, isNonNullType, hasDefaultValue);
        return `${formattedFieldString}: ${formattedTypeString}`;
    }
    wrapAstTypeWithModifiers(baseType, typeNode) {
        throw new Error(`You must override "wrapAstTypeWithModifiers" of OperationVariablesToObject!`);
    }
    formatFieldString(fieldName, isNonNullType, hasDefaultValue) {
        return fieldName;
    }
    formatTypeString(fieldType, isNonNullType, hasDefaultValue) {
        return fieldType;
    }
}
//# sourceMappingURL=variables-to-object.js.map